@@ -10,8 +10,8 @@ import time
 import requests as rq
 from pandas import DataFrame, Timestamp, Timedelta
 
-from getBitMEXtypes import bucketT, oTimestampT, symbolT
-from settings import LIVE_URL, TEST_URL, TC, STARTDATE_DFT
+from getBitMEXData.getBitMEXtypes import bucketT, oTimestampT, symbolT
+from getBitMEXData.settings import LIVE_URL, TEST_URL, TC, STARTDATE_DFT
 
 os.environ["TZ"] = "UTC"
 time.tzset()
